@@ -8,13 +8,16 @@ import collections
 import statsd
 
 from django.conf import settings
+from django.core import exceptions
 
 from django_statsd import utils
 
 logger = logging.getLogger(__name__)
 
-
-TRACK_MIDDLEWARE = getattr(settings, 'STATSD_TRACK_MIDDLEWARE', False)
+try:
+    TRACK_MIDDLEWARE = getattr(settings, 'STATSD_TRACK_MIDDLEWARE', False)
+except exceptions.ImproperlyConfigured:
+    TRACK_MIDDLEWARE = False
 
 
 class WithTimer(object):
@@ -39,11 +42,15 @@ class Client(object):
     class_ = statsd.Client
 
     def __init__(self, prefix='view'):
+        global_prefix = getattr(settings, 'STATSD_PREFIX', None)
+        if global_prefix:
+            prefix = '%s.%s' % (global_prefix, prefix)
         self.prefix = prefix
         self.data = collections.defaultdict(int)
 
     def get_client(self, *args):
-        prefix = '%s.%s' % (self.prefix, '.'.join(args))
+        args = [self.prefix] + list(args)
+        prefix = '.'.join(a for a in args if a)
         return utils.get_client(prefix, class_=self.class_)
 
     def submit(self, *args):
@@ -61,7 +68,7 @@ class Counter(Client):
 
     def submit(self, *args):
         client = self.get_client(*args)
-        for k, v in self.data:
+        for k, v in self.data.items():
             if v:
                 client.increment(k, v)
 
@@ -126,6 +133,9 @@ class StatsdMiddleware(object):
         cls.scope.timings = Timer(prefix)
         cls.scope.timings.start('total')
         cls.scope.counter = Counter(prefix)
+        cls.scope.counter.increment('hit')
+        cls.scope.counter_site = Counter(prefix)
+        cls.scope.counter_site.increment('hit')
         return cls.scope
 
     def process_request(self, request):
@@ -147,7 +157,13 @@ class StatsdMiddleware(object):
 
         # View name is defined as module.view
         # (e.g. django.contrib.auth.views.login)
-        self.view_name = view_func.__module__ + '.' + view_func.__name__
+        self.view_name = view_func.__module__
+
+        # CBV specific
+        if hasattr(view_func, '__name__'):
+            self.view_name = '%s.%s' % (self.view_name, view_func.__name__)
+        elif hasattr(view_func, '__class__'):
+            self.view_name = '%s.%s' % (self.view_name, view_func.__class__.__name__)
 
     @classmethod
     def stop(cls, *key):
@@ -155,6 +171,7 @@ class StatsdMiddleware(object):
             cls.scope.timings.stop('total')
             cls.scope.timings.submit(*key)
             cls.scope.counter.submit(*key)
+            cls.scope.counter_site.submit('site')
 
     def process_response(self, request, response):
         if TRACK_MIDDLEWARE:
@@ -219,11 +236,11 @@ def with_(key):
 
 def incr(key, value=1):
     if getattr(StatsdMiddleware.scope, 'counter', None):
-        StatsdMiddleware.scope.counter.incr(key, value)
+        StatsdMiddleware.scope.counter.increment(key, value)
 
 def decr(key, value=1):
     if getattr(StatsdMiddleware.scope, 'counter', None):
-        StatsdMiddleware.scope.counter.decr(key, value)
+        StatsdMiddleware.scope.counter.decrement(key, value)
 
 def wrapper(prefix, f):
     @functools.wraps(f)
